@@ -1,6 +1,6 @@
 package Ubic::Service::Plack;
 BEGIN {
-  $Ubic::Service::Plack::VERSION = '1.13';
+  $Ubic::Service::Plack::VERSION = '1.14';
 }
 
 use strict;
@@ -9,13 +9,12 @@ use warnings;
 # ABSTRACT: Helper for running psgi applications with ubic and plackup
 
 
-use base qw(Ubic::Service::Common);
+use base qw(Ubic::Service::Skeleton);
 
 use Params::Validate qw(:all);
 use Plack;
 
 use Ubic::Daemon qw(:all);
-use Ubic::Service::Common;
 
 
 my $plackup_command = $ENV{'UBIC_SERVICE_PLACKUP_BIN'} || 'plackup';
@@ -26,24 +25,28 @@ sub new {
     my $params = validate(@_, {
         server      => { type => SCALAR },
         app         => { type => SCALAR },
-        app_name    => { type => SCALAR },
+        app_name    => { type => SCALAR, optional => 1 },
         server_args => { type => HASHREF, default => {} },
         user        => { type => SCALAR, optional => 1 },
+        group       => { type => SCALAR | ARRAYREF, optional => 1 },
         status      => { type => CODEREF, optional => 1 },
         port        => { type => SCALAR, regex => qr/^\d+$/, optional => 1 },
         ubic_log    => { type => SCALAR, optional => 1 },
         stdout      => { type => SCALAR, optional => 1 },
         stderr      => { type => SCALAR, optional => 1 },
         pidfile     => { type => SCALAR, optional => 1 },
+        cwd => { type => SCALAR, optional => 1 },
+        env => { type => HASHREF, optional => 1 },
     });
 
-    $params->{pidfile} ||= "/tmp/$params->{app_name}.pid";
     return bless $params => $class;
 }
 
 sub pidfile {
     my $self = shift;
-    return $self->{pidfile};
+    return $self->{pidfile} if defined $self->{pidfile};
+    return "/tmp/$self->{app_name}.pid" if defined $self->{app_name};
+    return "/tmp/".$self->full_name.".pid";
 }
 
 sub bin {
@@ -78,8 +81,12 @@ sub bin {
 sub start_impl {
     my $self = shift;
 
-    my $daemon_opts = { bin => $self->bin, pidfile => $self->pidfile, term_timeout => 5 };
-    for (qw/ubic_log stdout stderr/) {
+    my $daemon_opts = {
+        bin => $self->bin,
+        pidfile => $self->pidfile,
+        term_timeout => 5, # TODO - configurable?
+    };
+    for (qw/ env cwd stdout stderr ubic_log /) {
         $daemon_opts->{$_} = $self->{$_} if defined $self->{$_};
     }
     start_daemon($daemon_opts);
@@ -108,25 +115,36 @@ sub user {
     return $self->SUPER::user;
 };
 
+sub group {
+    my $self = shift;
+    my $groups = $self->{group};
+    return $self->SUPER::group() if not defined $groups;
+    return @$groups if ref $groups eq 'ARRAY';
+    return $groups;
+}
+
 sub timeout_options {
-    return { start => { trials => 15, step => 0.1 }, stop => { trials => 15, step => 0.1 } };
+    # TODO - make them customizable
+    return {
+        start => { trials => 15, step => 0.1 },
+        stop => { trials => 15, step => 0.1 },
+    };
 }
 
 sub port {
     my $self = shift;
-    # we should leave only one of these, but I can't decide which one -- mmcleric
+    # we should leave only one of these, but I can't decide which one
+    # -- mmcleric
     return $self->{port} if defined $self->{port};
     return $self->{server_args}{port};
 }
 
-
 sub defaults {
     return ();
 }
 
 
 1;
-
 __END__
 =pod
 
@@ -136,7 +154,7 @@ Ubic::Service::Plack - Helper for running psgi applications with ubic and placku
 
 =head1 VERSION
 
-version 1.13
+version 1.14
 
 =head1 SYNOPSIS
 
@@ -146,7 +164,6 @@ version 1.13
         server_args => { listen => "/tmp/app.sock",
                          nproc  => 5 },
         app      => "/var/www/app.psgi",
-        app_name => 'app',
         status   => sub { ... },
         port     => 4444,
         ubic_log => '/var/log/app/ubic.log',
@@ -157,7 +174,8 @@ version 1.13
 
 =head1 DESCRIPTION
 
-This service is a common ubic wrap for psgi applications. It uses plackup for running these applications.
+This service is a common ubic wrap for psgi applications.
+It uses plackup for running these applications.
 
 =head1 NAME
 
@@ -165,7 +183,7 @@ Ubic::Service::Plack - ubic service base class for psgi applications
 
 =head1 VERSION
 
-version 1.13
+version 1.14
 
 =head1 METHODS
 
@@ -180,28 +198,28 @@ Parameters (mandatory if not specified otherwise):
 =item I<server>
 
 Server name from Plack::Server::* or Plack::Handler::* namespace.
-You can pass this param in both variants, for example 'Plack::Handler::FCGI' or just 'FCGI'.
+You can pass this param in both variants, for example 'Plack::Handler::FCGI' or
+just 'FCGI'.
 
 =item I<server_args> (optional)
 
-Hashref with options that will passed to concrete Plack server specified by C<server> param. See concrete server docimentation for possible options.
-You can also pass here such options as 'env' to override defaults. In this case you must use long option names ('env' insted of 'E').
+Hashref with options that will be passed to concrete Plack server specified by
+C<server> param.
+See concrete server docimentation for possible options.
+You can also pass here such options as 'env' to override defaults.
 
 =item I<app>
 
 Path to .psgi app.
 
-=item I<app_name>
-
-Name of your application (uses for constructing path for storing pid-file of your app).
-
 =item I<status> (optional)
 
 Coderef to special function, that will check status of your application.
 
 =item I<port> (optional)
 
-Port on which your application works. Ubic-ping will use this info for HTTP status checking of your application.
+Port on which your application works. C<ubic.ping> will use this info for HTTP
+status checking of your application.
 
 =item I<ubic_log> (optional)
 
@@ -217,16 +235,54 @@ Path to stderr log of plackup.
 
 =item I<user> (optional)
 
-User name. If specified, real and effective user identifiers will be changed before execing any psgi applications.
+User under which plackup will be started.
+
+=item I<group> (optional)
+
+Group under which plackup will be started. Default is all user groups.
+
+=item I<cwd> (optional)
+
+Change working directory before starting a daemon.
+
+=item I<env> (optional)
+
+Modify environment before starting a daemon. Must be a plain hashref if
+specified.
 
 =item I<pidfile> (optional)
 
 Pidfile for C<Ubic::Daemon> module.
 
-If not specified, it will be derived from I<app_name>.
+If not specified, it will be derived from service's name or from I<app_name>,
+if provided.
+
+Pidfile is:
+
+=over
+
+=item *
+
+I<pidfile> option value, if provided;
+
+=item *
+
+C</tmp/APP_NAME.pid>, where APP_NAME is I<app_name> option value, if it's
+provided;
+
+=item *
+
+C</tmp/SERVICE_NAME.pid>, where SERVICE_NAME is service's full name.
 
 =back
 
+=item I<app_name>
+
+Name of your application. DEPRECATED.
+
+It was used in older releases for constructing the path for storing pid-file of
+your app).
+
 =back
 
 =item C<pidfile()>
@@ -239,9 +295,12 @@ Get command-line with all arguments in the arrayref form.
 
 =for Pod::Coverage defaults
 
+=back
+
 =head1 FUTURE DIRECTIONS
 
-Some kind of basic HTTP/socket (depending on server type) ping in status phase would be handy.
+Some kind of basic HTTP/socket (depending on server type) ping in status phase
+would be handy.
 
 =head1 AUTHORS
 
@@ -259,7 +318,7 @@ Vyacheslav Matjukhin <mmcleric@yandex-team.ru>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011 by Yandex LLC.
+This software is copyright (c) 2012 by Yandex LLC.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
